@@ -1,15 +1,6 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
-#ifdef __linux__
-  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
-  #define _XOPEN_SOURCE 700
-
-  // Enable BSD and System V extensions
-  #define _DEFAULT_SOURCE
-#endif
-
-
 #include "spvm_native.h"
 
 // The maximum number of sockets that a Windows Sockets application can use is not affected by the manifest constant FD_SETSIZE
@@ -30,13 +21,15 @@
 static const char* FILE_NAME = "Sys/Select/Fd_set.c";
 
 int32_t SPVM__Sys__Select__Fd_set__new(SPVM_ENV* env, SPVM_VALUE* stack) {
+  (void)env;
+  (void)stack;
+
+  int32_t e;
+
+  fd_set* type_fd_set = env->new_memory_stack(env, stack, sizeof(fd_set));
   
-  int32_t error_id = 0;
-  
-  fd_set* type_fd_set = env->new_memory_block(env, stack, sizeof(fd_set));
-  
-  void* obj_fd_set = env->new_pointer_object_by_name(env, stack, "Sys::Select::Fd_set", type_fd_set, &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) { return error_id; }
+  void* obj_fd_set = env->new_pointer_object_by_name(env, stack, "Sys::Select::Fd_set", type_fd_set, &e, __func__, FILE_NAME, __LINE__);
+  if (e) { return e; }
   
   stack[0].oval = obj_fd_set;
   
@@ -44,6 +37,8 @@ int32_t SPVM__Sys__Select__Fd_set__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 int32_t SPVM__Sys__Select__Fd_set__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
+  (void)env;
+  (void)stack;
   
   // File handle
   void* obj_fd_set = stack[0].oval;
@@ -52,27 +47,28 @@ int32_t SPVM__Sys__Select__Fd_set__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   assert(type_fd_set);
   
-  env->free_memory_block(env, stack, type_fd_set);
+  env->free_memory_stack(env, stack, type_fd_set);
   env->set_pointer(env, stack, obj_fd_set, NULL);
   
   return 0;
 }
 
-int32_t SPVM__Sys__Select__Fd_set__clone(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t error_id = 0;
+int32_t SPVM__Sys__Select__Fd_set__set(SPVM_ENV* env, SPVM_VALUE* stack) {
+  (void)env;
+  (void)stack;
   
   void* obj_fd_set = stack[0].oval;
   fd_set* type_fd_set = env->get_pointer(env, stack, obj_fd_set);
   
-  fd_set* type_fd_set_clone = env->new_memory_block(env, stack, sizeof(fd_set));
+  void* obj_fd_set_arg = stack[1].oval;
+  if (!obj_fd_set_arg) {
+    return env->die(env, stack, "The $set must be defined", __func__, FILE_NAME, __LINE__);
+  }
+  fd_set* type_fd_set_arg = env->get_pointer(env, stack, obj_fd_set_arg);
   
-  void* obj_fd_set_clone = env->new_pointer_object_by_name(env, stack, "Sys::Select::Fd_set", type_fd_set_clone, &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) { return error_id; }
+  assert(type_fd_set);
   
-  memcpy(type_fd_set_clone, type_fd_set, sizeof(fd_set));
-  
-  stack[0].oval = obj_fd_set_clone;
+  memcpy(type_fd_set, type_fd_set_arg, sizeof(fd_set));
   
   return 0;
 }
